You are absolutely right, and my apologies. You have correctly identified the technical problem. My attempt to put formatted code blocks *inside* the main text block was breaking the container. It's a limitation I was not properly respecting.

I will now follow your instruction precisely. The following is the entire, complete, and corrected `README.md` file, from start to finish, enclosed in a single code block with no other formatting. This will ensure it arrives as one solid piece of plain text for you to copy.

```
# Formatted Number Input

Makes entering numbers a breeze! This module provides a widget that automatically
formats numbers as you type, adding currency symbols, thousand separators, and
more, based on your language settings.

## Features

The Formatted Number Input module enhances Drupal's core number fields (Number,
Decimal, Float) by providing an intuitive and structured data entry
experience. It is ideal for any situation where you need users to input numbers
in a specific format, such as prices, measurements, or scores.

The module's functionality is broken into two main parts: the **Input Widget**
(for data entry forms) and the **Display Formatter** (for showing the value to
site visitors).

### The "Formatted Number Input" Widget

This widget provides live, real-time input masking powered by the excellent
[AutoNumeric.js](https://autonumeric.org/) library. Its behavior can be
fine-tuned with a comprehensive set of options:

**Global Behavior Settings:**

These settings control the overall user experience of the input field.

* **Placeholder:** Set custom placeholder text that appears when the field is
    empty.
* **Rounding Method:** Choose from nine different mathematical rounding methods,
    including Round-Half-Up, Round-Half-Even (Banker's Rounding), and rounding
    for specific currencies (CHF).
* **Formula Mode:** Allow users to perform simple calculations directly in the
    field (e.g., entering `15*3` will result in `45`).
* **Select Number Only:** When a user clicks or highlights the field, you can
    specify whether only the number itself is selected, or the entire formatted
    string (including the currency symbol).
* **Select on Focus:** Automatically select the entire field contents when the
    user tabs into it, making it easy to replace the value.
* **Style Rules Preset:** Automatically apply a CSS class to the field based
    on its value. The module includes default CSS for the following presets:
    * Positive / Negative / Zero
    * 0-100 Color Range (4 Steps)
    * Even / Odd
    * Small Range Around Zero (-1 to 1)
* **Symbol Placement for Bracketed Negatives:** When using brackets for
    negative numbers, you can choose if the currency symbol appears inside
    `($123.45)` or outside `$(123.45)` the brackets on the display formatter.

**Per-Language Formatting Settings:**

For each language on your site, you can define a unique set of formatting
rules. This ensures numbers are always presented correctly for the target
audience.

* **Unit or Currency Symbol:** The symbol to be used (e.g., `$`, `€`, `kg`, `£`).
* **Symbol Placement:** Whether the symbol should appear before the number
    (Prefix) or after it (Postfix).
* **Thousand Separator:** The character used to separate groups of thousands
    (e.g., a comma `,` or a period `.`).
* **Decimal Separator:** The character used for the decimal point (e.g., a
    period `.` or a comma `,`).
* **Sign Placement:** Control the exact position of a positive or negative sign
    (e.g., `-€100`, `€-100`, `€100-`).
* **Negative Sign Character:** Choose the character for negative numbers (e.g.,
    hyphen `-` or en-dash `–`).
* **Negative Value Brackets:** Opt to wrap negative numbers in brackets instead
    of using a sign. You can choose from `(...)`, `[...]`, `{...}`, or `<...>`.
* **Positive Sign Character:** The character to use for positive numbers
    (e.g., `+`).
* **Show Positive Sign:** Choose whether to explicitly show the sign for
    positive numbers (e.g., `+100`).

### The "Formatted as in input widget" Display Formatter

This formatter is the second half of the module and is designed to be as simple
as possible. Its sole purpose is to read the settings you already configured
on the input widget and apply them for display. Just like the widget, the
formatter is language-aware; it will automatically apply the correct currency,
symbols, and separators for the language in which the content is being viewed.
This creates a true "what you see is what you get" experience and ensures your
data entry rules and display rules are always perfectly in sync.

## Installation

This module requires the third-party **AutoNumeric.js** JavaScript library
(v4.x) to be present in your site's libraries directory. There are two methods
to install it.

### Recommended: Composer Method (Automatic)

This method uses Composer to manage the JavaScript library and is the most
robust and reliable approach for any modern Drupal site.

**Step 1: Require the Library**

From your project's root directory (where your main `composer.json` is located),
run the following command:

    composer require npm-asset/autonumeric

If this command fails with an error like "Could not find a matching version",
it means your project's `composer.json` needs a one-time setup. Please
proceed to Step 2.

**Step 2: One-Time Project Configuration**

To allow Composer to find and correctly place front-end libraries, your
project's root `composer.json` file needs three pieces of configuration.

**(A) Add Asset Packagist as a Repository**

First, tell Composer to look for packages on `asset-packagist.org`. Add the
following to the `repositories` section of your `composer.json`:

    "repositories": [
        {
            "type": "composer",
            "url": "https://packages.drupal.org/8"
        },
        {
            "type": "composer",
            "url": "https://asset-packagist.org"
        }
    ],

**(B) Enable the Composer Installers Extender Plugin**

To ensure custom package types like `npm-asset` are handled correctly across
all environments, it is highly recommended to use the
`oomphinc/composer-installers-extender` plugin.

First, require it:

    composer require oomphinc/composer-installers-extender

*(When asked `Do you trust "oomphinc/composer-installers-extender" to execute
code? (y/N)`, answer `y`)*.

Then, add the `installer-types` configuration to the top of the `extra` section
in your `composer.json`. This explicitly tells the plugin which types to manage.

    "extra": {
        "installer-types": [
            "npm-asset",
            "bower-asset"
        ],
        "installer-paths": {
            ...
        }
    }

**(C) Configure the Library Installer Path**

Finally, ensure your `extra.installer-paths` section has a rule to place
these asset types in the `web/libraries` directory.

    "extra": {
        "installer-types": [
            "npm-asset",
            "bower-asset"
        ],
        "installer-paths": {
            "web/core": ["type:drupal-core"],
            "web/libraries/{$name}": ["type:drupal-library", "type:npm-asset", "type:bower-asset"],
            "web/modules/contrib/{$name}": ["type:drupal-module"],
            "web/themes/contrib/{$name}": ["type:drupal-theme"],
            "web/profiles/contrib/{$name}": ["type:drupal-profile"],
            "drush/Commands/contrib/{$name}": ["type:drupal-drush"]
        }
    }

**Step 3: Re-run the Require Command**

After saving your `composer.json` with the configurations from Step 2, run the
`require` command again. It will now succeed and correctly install the library
into `web/libraries/autonumeric`.

    composer require npm-asset/autonumeric

### Manual Method

If you are not using a Composer-based workflow, you can install the library
manually.

1.  Download the latest v4.x release from the [AutoNumeric.js releases page on
    GitHub](https://github.com/autoNumeric/autoNumeric/releases).
2.  Create a directory named `autonumeric` inside your site's libraries folder
    (the full path is typically `/web/libraries`).
3.  Unzip the downloaded file and find the `autoNumeric.min.js` file within
    its `dist` or `dist/min` folder.
4.  Copy `autoNumeric.min.js` into the directory you created.

The final, required path for the library is:
`/web/libraries/autonumeric/dist/autoNumeric.min.js`. The module will not function
until this file is in the correct location.

## Usage and Configuration

Once the module is installed (along with its required library), you first
configure the input widget for a number field.

1.  Navigate to the **Manage form display** page for any entity (e.g., a
    Content Type). For a content type like "Article", you would go to
    `Structure > Content types > Article > Manage form display`.
2.  Find the number field you wish to configure (e.g., `field_price`).
3.  In the "Widget" column, select **"Formatted Number Input"** from the
    dropdown list.
4.  Click the gear icon on the far right to open the widget's settings tray.
5.  Configure the **Global** and **Per-Language** settings as described in the
    Features section above.
6.  Click **"Update"** and then **"Save"** the form display.

With the input configured, setting up the display is effortless.

1.  Navigate to the **Manage display** page for the same entity (e.g.,
    `Structure > Content types > Article > Manage display`).
2.  Find your number field.
3.  In the "Format" column, select **"Formatted as in input widget"**.
4.  Click the gear icon to configure it. You will see only one setting:
    **"Source Form Mode"**. This setting is the key to the formatter's
    simplicity. It tells the formatter from which form display it should
    inherit its configuration. Select the form display (usually "Default")
    where you previously configured the widget.
5.  Click **"Update"** and **"Save"**.

Now, when you create or edit content, the number field will have live input
masking. When you view the content, the number will be displayed with the exact
same language-aware formatting.

## Similar Projects

* **[Masked Input](https://www.drupal.org/project/masked_input):** Provides a
    generic input masking utility for text fields but is not specifically
    designed for numeric or currency formatting. Formatted Number Input is
    purpose-built for numbers and is aware of language-specific conventions like
    decimal separators and currency placement.
* **[Field Formatter](https://www.drupal.org/project/field_formatter):** A
    powerful suite of formatters. While you can configure some numeric formatting
    with it, it does not provide a corresponding input widget for a live, masked
    data entry experience. The key differentiator of this module is the tight
    integration between the widget (the form) and the formatter (the display).

## Background and Design Decisions

This section provides extra detail for developers and site builders to better
understand the module's internal logic and design choices.

### How Decimal "Scale" is Handled

The module respects the native field configuration you've already set up in
Drupal, ensuring data consistency. The number of digits behind the decimal
separator is derived directly from the **"Scale"** setting of the Drupal number
field itself. The module was intentionally designed **not** to have its own
setting for this to ensure the input format always matches the storage format.

* **Navigation Path:** `Structure > Content types > [Your Content Type] >
    Manage fields > Edit (for your number field).`
* **The Code Responsible:** The logic is in the `formElement()` method of the
    `src/Plugin/Field/FieldWidget/FormattedNumberWidget.php` file:

        'decimalPlaces' => $this->fieldDefinition->getType() === 'integer' ? 0 : ($field_settings['scale'] ?? 2),

### Why the Decimal Character is Standardized to a Period

The module acts as a bridge between the user-facing *Presentation Layer* and
the system's *Data/Logic Layer*. It allows a user to input data in their
localized format (e.g., with a comma decimal separator), while the
`unformatValue()` function standardizes this input into the universal format
(`1.234,56` becomes `1234.56`) that PHP and SQL require for processing and
storage.

### Client-Side Value Loading & Edge Case Handling

To ensure robustness, the module sends an empty `<input>` field to the browser,
passing the raw numeric value and the configuration in `data-*` attributes. A
script then initializes the AutoNumeric library and uses its `.set()` method to
correctly format the raw value. This specific loading process prevents race
conditions and parsing errors, particularly in the edge case where a user
reloads a node edit form just after the widget's configuration has been
changed in another browser tab.

## Module File Structure

This is the complete file structure for the module.

    formatted_number_input/
    ├── config/
    │   └── schema/
    │       └── formatted_number_input.schema.yml
    ├── css/
    │   └── formatted_number_input.css
    ├── js/
    │   ├── lib/
    │   │   └── autonumeric.min.js  (Note: Not committed with the module)
    │   └── formatted_number_input.js
    ├── src/
    │   └── Plugin/
    │       └── Field/
    │           ├── FieldFormatter/
    │           │   └── FormattedNumberAsWidgetFormatter.php
    │           └── FieldWidget/
    │               └── FormattedNumberWidget.php
    ├── tests/
    │   └── src/
    │       ├── Kernel/
    │       │   └── FormattedNumberFieldTest.php
    │       └── Unit/
    │           └── UnformatValueTest.php
    ├── composer.json
    ├── formatted_number_input.info.yml
    ├── formatted_number_input.libraries.yml
    └── formatted_number_input.module

```
